@@ -11,5 +11,5 @@
 # ]
 
 #from .sdd2rdf import *
-from .sdd2setl import sdd2setl, sdd2setl_main
+from .sdd2setl import sdd2setl, sdd2setl_main, resolve
 #from .sddmarkup import sddmarkup_main
